{% extends "projector/project/task/attachment.html" %}

{% block col-main-content %}
<h1>Task {{ task.id }}: {{ task.summary }}</h1>
<label>{{ attachment.name }}</label>
    <p>
        <pre>{{ attachment.body }}</pre>
    </p>
{% endblock %}
