{% extends "base.html" %}

{% load i18n %}

{% block extra-head %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{{ MEDIA_URL }}projector/css/browser.css" />
    <link rel="stylesheet" type="text/css" href="{{ MEDIA_URL }}projector/css/projector.css" />
{% endblock %}

{% block menu-top %}
    {{ block.super }}
    {% include "projector/menu.html" %}
{% endblock %}

{% block col-left %}
    
    <div class="richtemplates-panel">
	    <h5>{% trans "Quicklinks" %}</h5>
	    <div class="richtemplates-panel-content">
	    	
			<ul class="nav-vertical">
                <li><a href="{% url projector_project_list %}">{% trans "Projects" %}</a></li>
	    	</ul>

	    </div>
	</div>

{% endblock %}


