{% extends "projector/home.html" %}

{% load i18n %}

{% block col-left %}
    {{ block.super }}
    <div class="richtemplates-panel">
        <h5>{% trans "Projects statistics" %}</h5>
	    <div class="richtemplates-panel-content">
	        <table class="form-table">
                <tr>
                    <td><label>{% trans "All projects count" %}</label></td>
                    <td>{{ project_list.count }}</td>
                </tr>
            </table>
	    </div>
    </div>
{% endblock %}

{% block col-main-title %}{% trans "Projects List" %}{% endblock %}

{% block col-main-content %}

    {% load pagination_tags %}
    {% load sorting_tags %}

    {% autosort user_list %}
    {% autopaginate user_list %}

    <table class="datatable">
        <thead class="datatable-thead">
            <tr class="datatable-thead-subheader">
                <th>{% anchor name _("Name") %}</th>
                <th>{% anchor first_name _("First name") %}</th>
                <th>{% anchor last_name _("Last name") %}</th>
                <th>{% anchor date_joined _("Joined") %}</th>
            </tr>
        </thead>
        <tbody class="datatable-tbody">
            {% for user in user_list %}
            <tr class="{% cycle "odd" "even" %} hoverable">
                <td><a class="block-link" href="{{ user.get_absolute_url }}">{{ user }}</a></td>
                <td>{{ user.first_name }}</td>
                <td>{{ user.last_name }}</td>
                <td>{{ user.date_joined }}</td>
            </tr>
            {% endfor %}
        </tbody>
    </table>

    {% paginate %}
{% endblock %}


