{% extends "projector/project/workflow/detail.html" %}

{% load markup %}
{% load i18n %}

{% block col-single-title %}{{ project.name }}{% endblock %}

{% block col-single-extra %}
<div class="richtemplates-panel">    
    <h5>{% trans "Workflow schema" %}</h5>
    <div class="richtemplates-panel-content">
        {% block workflow-menu %}{{ block.super }}{% endblock %}

        <form method="post" action=".">
            {% csrf_token %}
            {{ formset.management_form }}
            {% for form in formset.forms %}
            <div class="richblock">
                <table class="form-table">
                    {% include "richtemplates/forms/form.html" %}
                </table>
            </div>
            {% endfor %}
            <div>
                <input id="id_submit" type="submit" name="submit"
                    value="{% trans "Update" %}"/>
                <input type="button" onclick="window.location='{% spaceless %}
                    {{ project.get_workflow_url }}
                    {% endspaceless %}'" value="{% trans "Cancel" %}"/>
            </div>            
        </form>
    </div>
</div>
{% endblock col-single-extra %}

