{% extends "richtemplates/layout/menu_top.html" %}
{% load i18n %}
{% load gravatar_tags %}

{% block menu-top-left %}
    <li><a href="/">Home</a></li>
    <li><a href="{% url projector_home %}">Projector</a></li>
{% endblock %}

{% block menu-top-right %}
    <li>
    {% if not user.is_authenticated %}
        <a href="{% url auth_login %}">{% trans "Login" %}</a>
    {% else %}
        <a href="{% url auth_logout %}">{% trans "Logout" %}</a>
    {% endif %}
    </li>
    {% if user.is_authenticated and user.is_staff %}
    <li><a href="{% url admin:index %}">Admin panel</a></li>
    {% endif %}

    {% if user.is_authenticated %}
    <li><a href="{% url projector_dashboard %}"
           class="show-tipsy-bottom"
           title="{% trans "Manage your account" %}"
           >{% trans "Dashboard" %}</a>
    </li>
    <li>{% trans "Logged as" %} <a href="{% url projector_users_profile_detail user.username %}"
        class="show-tipsy-bottom"
        title="{% trans "Show user's public profile" %}">{{ user }}</a>
    </li>
    <li><img src="{% gravatar_for_user user 16 %}"
             alt="{% trans "Avatar" %}"
             style="padding:0; margin:0"
             width="16"
             height="16"/>
     </li>
    {% endif %}

{% endblock %}

