{% load i18n %}
{% load guardian_tags %}

<div class="menu-top-submenu">
    <ul class="menu-top-left">
        <li><a href="{% url projector_home %}">{% trans "Projector homepage" %}</a></li>
        <li><a href="{% url projector_project_list %}">{% trans "Projects" %}</a></li>
    </ul>
    <ul class="menu-top-right">
    </ul>
</div>
