{% extends "projector/home.html" %}

{% block col-main-title %}Project Category List{% endblock %}

{% block col-main-content %}

    {% load pagination_tags %}
    {% autopaginate project_category_list %}

    <table class="datatable">
    <tbody class="datatable-tbody">
        {% for project_category in project_category_list %}
        <tr>
            <td><a href="{{ project_category.get_absolute_url }}">{{ project_category.name }}</a></td>
        </tr>
        {% endfor %}
    </tbody>
    </table>
    {% paginate %}
{% endblock %}
