{% extends "projector/project/detail.html" %}

{% block extra-head %}
    {{ block.super }}
    <script type="text/javascript">
        $(document).ready(function(){
            jQuery('#id_name').slugify('#id_slug');
        });
    </script>
{% endblock %}

{% load i18n %}

{% block col-single-extra %}

<div class="richtemplates-panel">
    <h5>{% trans "Project's edit panel" %}</h5>
    <div class="richtemplates-panel-content">
        <form action="." method="post">
            {% csrf_token %}
            <table class="form-table">
                {% include "richtemplates/forms/form.html" %}
            </table>
            <div>
                <input id="id_submit_project" type="submit" name="submit_project"
                value="{% trans "Save project" %}"/>
            </div>
        </form>
    </div>
</div>

<div class="richtemplates-panel">
    <h5>{% trans "Project's configuration panel" %}</h5>
    <div class="richtemplates-panel-content">
        <form action="." method="post">
            {% csrf_token %}
            {% with form_config as form %}
            <table class="form-table">
                {% include "richtemplates/forms/form.html" %}
            </table>
            {% endwith %}
            <div>
                <input id="id_submit_config" type="submit" name="submit_config"
                value="{% trans "Save config" %}"/>
            </div>
        </form>
    </div>
</div>

{% endblock %}

