{% extends "projector/home.html" %}

{% block extra-head %}
    {{ block.super }}
    <script type="text/javascript">
        $(document).ready(function(){
            jQuery('#id_name').slugify('#id_slug');
        });
    </script>
{% endblock %}

{% load i18n %}

{% block col-main-title %}{% trans "Create new project" %}{% endblock %}

{% block col-main-content %}
    <form action="." method="post">
        {% csrf_token %}
        <table class="form-table">
            {% include "richtemplates/forms/form.html" %}
        </table>
        <div>
            <input id="id_submit" type="submit" name="submit"
            value="{% trans "Create" %} {% trans "project" %}"/>
            <input type="button" onclick="window.location='{% spaceless %}
                {% if form.instance.id %}
                    {{ form.instance.get_absolute_url }}
                {% else %}
                    {% url projector_project_list %}
                {% endif %}
                {% endspaceless %}'" value="{% trans "Cancel" %}"/>
        </div>
    </form>
{% endblock %}

