{% extends "projector/project/milestones/home.html" %}

{% load markup %}
{% load i18n %}

{% block col-single-title %}{{ project.name }}{% endblock %}

{% block col-single-extra %}
<div class="richtemplates-panel">    
    <h5>{% trans "Milestone detail" %}</h5>
    <div class="richtemplates-panel-content">
        {% block milestones-menu %}{{ block.super }}{% endblock %}

        <div class="richblock">
            <table class="richblock-properties">
                <tbody>
                    <tr>
                        <th>{% trans "Name" %}</th>
                        <td>{{ milestone.name }}</td>
                    </tr>
                    <tr>
                        <th>{% trans "Deadline" %}</th>
                        <td>{{ milestone.deadline }}</td>
                    </tr>
                </tbody>
            </table>
            <h2>{% trans "Description" %}:</h2>
            <div class="block-rst">
                {{ milestone.description|safe|restructuredtext }}
            </div>
            
        </div>

        {% include "projector/project/milestones/progress_table.html" %}

    </div>
</div>
{% endblock col-single-extra %}

