{% extends "base_1col.html" %}

{% load i18n %}

{% block col-single-title %}{% trans "Fork" %} ({% trans "Step" %} {{ step }}/{{ step_count }}){% endblock %}
{% block col-single-content %}
    <ul class="messages">
        <li class="message message-info">
            {% blocktrans %}
            Fork external project.
            {% endblocktrans %}
        </li>
        {% if form.help_text %}
        <li class="message message-info">{{ form.help_text }}</li>
        {% endif %}
    </ul>

    <form action="." method="post">{% csrf_token %}
        <table class="form-table">
            {% include "richtemplates/forms/form.html" %}
        </table>
        <input type="hidden" name="{{ step_field }}" value="{{ step0 }}" />
        {{ previous_fields|safe }}
        <input type="submit" name="submit" value="{% trans "Submit" %}"/>
    </form>
{% endblock %}
