{% extends "projector/home.html" %}

{% block col-main-title %}{{ project_category.name }}{% endblock %}

{% block col-main-content %}
    <h1>{{ project_category.name }}</h1>

    <h2>Related projects:</h2>
    <ul class="nav-vertical">
        {% for project in project_category.project_set.all %}
        <li>
            <a href="{{ project.get_absolute_url }}">{{ project.name }}</a>
        </li>
        {% endfor %}
    </ul>
{% endblock %}

