{% extends "projector/project/members/home.html" %}

{% load i18n %}
{% load pagination_tags %}
{% load sorting_tags %}
{% load native %}

{% block extra-head %}{{ block.super }}
    {{ form.media }}
    {% autocomplete_field form.member %}
{% endblock %}

{% block col-single-extra %}
<div class="richtemplates-panel">
    <h5>{% trans "Add member" %}</h5>
    <div class="richtemplates-panel-content">
        {% block members-menu %}{{ block.super }}{% endblock %}
        <form action="." method="post">
            {% csrf_token %}
            <table class="form-table">
                {% include "richtemplates/forms/form.html" %}
            </table>
            <div>
                <input id="id_submit" type="submit" name="submit"
                    value="{% trans "Submit" %}"/>
                <input type="button"
                       value="{% trans "Cancel" %}"
                       onclick="window.location='{{ form.instance.project.get_members_url }}'"/>
            </div>
        </form>
    </div>
</div>
{% endblock %}

