{% extends "base.html" %}


    <!-- Content -->
    {% block content %}
    
        <!-- One Main Panel -->
        <div id="col_single">
        {% block col-single %}
            <div class="richtemplates-panel">
                <h5>{% block col-single-title %}Single column base template{% endblock %}</h5>
                <div class="richtemplates-panel-content">
                    {% block col-single-content %}
                    Lorem ipsum dolor ...
                    {% endblock %}
                </div>
            </div>
        {% endblock col-single %}
        </div>
        
    {% endblock content %}

