{% extends "projector/project/repository/browse.html" %}

{% load i18n %}
{% load native %}
{% load breadcrumber %}

{% block col-left %}
{% with file_old as root %}{{ block.super }}{% endwith %}
{% endblock %}

{% block browse-content %}
{% if diff_content %}
    <div class="diffblock">
        {{ differ.as_html|safe }}
    </div>
{% else %}
    <ul class="messages">
        <li class="message message-warning">
            {% trans "No changes have been made between revisions" %}
            <a class="show-tipsy"
               href="{% url projector_project_sources_browse project.author.username project.slug file_old.changeset.id '' %}"
               title="{% trans "Show changeset" %}">{{ file_old.changeset.revision }}:{{ file_old.changeset.id }}</a>
            -
            <a class="show-tipsy"
               href="{% url projector_project_sources_browse project.author.username project.slug file_new.changeset.id '' %}"
               title="{% trans "Show changeset" %}">{{ file_new.changeset.revision }}:{{ file_new.changeset.id }}</a>
        </li>
    </ul>
{% endif %}
{% endblock %}
