{% extends "projector/home.html" %}

{% load i18n %}

{% block extra-head %}{{ block.super }}
    {{ form.media }}
{% endblock %}

{% block col-left %}{% endblock %}

{% block col-main-title %}{% trans "Projector global settings" %}{% endblock %}
{% block col-main-content %}

<form method="post">
    {% csrf_token %}
    <table class="form-table">
        {% include "richtemplates/forms/form.html" %}
        <tr>
            <td colspan="2">
                <input type="submit" name="submit" value="Save" />
            </td>
        </tr>
    </table>
</form>

{% endblock %}
