{% extends "projector/project/members/home.html" %}

{% load i18n %}
{% load native %}

{% block extra-head %}{{ block.super }}
    {{ form.media }}
{% endblock %}

{% block col-single-extra %}

<div class="richtemplates-panel">
    <h5>{% trans "Project's member" %}: {{ membership.member }}</h5>
    <div class="richtemplates-panel-content">
    {% block members-menu %}{{ block.super }}{% endblock %}
    {% if project.is_public %}
        <ul class="messages">
            <li class="message message-info">
            {% blocktrans %}This is public project so anyone may view it or clone it's repository even if
            does NOT have proper permissions.{% endblocktrans %}
            </li>
        </ul>
    {% endif %}

    <form id="id_form_perms" action="." method="post">
        {% csrf_token %}
        <table class="form-table">
            {% include "richtemplates/forms/form.html" %}
        </table>
        <p>
            <input type="submit" name="Update" class="richbutton" />
        </p>
    </form>

    </div>
</div>
{% endblock %}


