{% extends "projector/project/detail.html" %}

{% load i18n %}

{% block col-single-extra %}

<div class="richtemplates-panel">
    <h5>{% trans "Project's fork process" %}</h5>
    <p>
        {% blocktrans %}
        You are about to create a fork of the <strong>{{ project }}</strong>.
        {% endblocktrans %}
    </p>
    <div class="richtemplates-panel-content">
        <form action="." method="post">
            {% csrf_token %}
            <table class="form-table">
                {% include "richtemplates/forms/form.html" %}
            </table>
            <div>
                <input id="id_submit"
                       type="submit"
                       name="submit"
                       value="{% trans "Fork project" %}"/>
            </div>
        </form>
    </div>
</div>

{% endblock %}

