{% extends "projector/project/members/home.html" %}

{% load i18n %}
{% load pagination_tags %}
{% load sorting_tags %}
{% load native %}

{% block col-single-extra %}
<div class="richtemplates-panel">
    <h5>{% trans "Remove member" %}</h5>
    <div class="richtemplates-panel-content">
        {% block members-menu %}{{ block.super }}{% endblock %}
        <ul class="messages">
            <li class="message message-warning">{% trans "Are you sure you want to remove member" %} {{ membership.member }}?</li>
        </ul>

        <div class="richblock">
            <h2>{% trans "Removing objects" %}</h2>
            <ul>{{ to_delete|unordered_list }}</ul>

            <h2>{% trans "Permissions currently given to member" %} {{ membership.member }}</h2>
            <ul>
                {% for perm in member_perms %}
                <li>{{ perm.permission.name }}</li>
                {% endfor %}
            </ul>
        </div>

        <form action="." method="post">
            {% csrf_token %}
            <table class="form-table">
                {% include "richtemplates/forms/form.html" %}
            </table>
            <div>
                <input id="id_submit" type="submit" name="submit"
                    value="{% trans "Confirm" %}"/>
                <input type="button"
                       value="{% trans "Back to project" %}"
                       onclick="window.location='{{ project.get_members_url }}'"/>
            </div>
        </form>
    </div>
</div>
{% endblock %}


