{% load i18n %}
{% trans "Project" %}: {{ task.project.name }}
{% trans "Task" %}: #{{ task.id }} - {{ task.summary }}
{% trans "Link" %}: {{ task_url }}

{% trans "Created at" %}: {{ task.created_at }}
{% trans "Reported by" %}: {{ task.author }}
{% if task.revision > 1 %}
{% trans "Edited at" %}: {{ task.edited_at }}
{% trans "Edited by" %}: {{ task.author }}
{% endif %}
{% trans "Component" %}: {{ task.component }}
{% trans "Status" %}: {{ task.status }}
{% trans "Priority" %}: {{ task.priority }}

{% trans "Content" %}
{% for x in _("Content") %}={% endfor %}

{{ task.description }}

{# Comment if necessary #}
{% if task.current_revision and task.current_revision.comment %}

{% with _("Comment by") as comment_by %}

{% for x in comment_by %}={% endfor %}={% for x in task.current_revision.author.username %}={% endfor %}
{{ comment_by }} {{ task.current_revision.author }}
{% for x in comment_by %}={% endfor %}={% for x in task.current_revision.author.username %}={% endfor %}

{{ task.current_revision.comment }}

{% endwith %}

{% endif %}
