{% extends "richtemplates/base_1col.html" %}

{% load i18n %}

{% block title %}404 - {% trans "Page unavailable" %}{% endblock %}
{% block content %}
<div id="col_single">
    <div class="richtemplates-panel">
        <h5>{% trans "Page unavailable" %}</h5>
        <div class="richtemplates-panel-content">
            <h1>{% trans "Page unavailable" %}</h1>
            <ul class="messages">
                <li class="message message-error">{% trans "We are sorry, but this page does not exist" %}</li>
            </ul>
        </div>
    </div>
</div>
{% endblock %}
