{% extends "projector/project/repository/browse.html" %}

{% load i18n %}
{% load native %}
{% load breadcrumber %}

{% block browse-content %}
<div id="repo-browser">
    {% block browse-content-info %}{{ block.super }}{% endblock %}
    <div class="codeblock">
        {% annotate_content root linenos=true anchorlinenos=true lineanchors=line cssclass="code-highlight" %}
    </div>

</div>
{% endblock %}
